# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import template_cn_common
from . import template_cn
from . import template_cn_large_bis
from . import account_move
